/****************************************************************************
** Meta object code from reading C++ file 'settings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../settings.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'settings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ArkSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto ArkSettings::qt_create_metaobjectdata<qt_meta_tag_ZN11ArkSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ArkSettings",
        "showEncryptionWarningChanged",
        "",
        "defaultOpenActionChanged",
        "openDestinationFolderAfterExtractionChanged",
        "closeAfterExtractionChanged",
        "preservePathsChanged",
        "extractToSubfolderChanged",
        "splitterSizesChanged",
        "showInfoPanelChanged",
        "disabledPluginsChanged",
        "limitPreviewFileSizeChanged",
        "previewFileSizeLimitChanged",
        "showEncryptionWarning",
        "isShowEncryptionWarningImmutable",
        "defaultOpenAction",
        "isDefaultOpenActionImmutable",
        "openDestinationFolderAfterExtraction",
        "isOpenDestinationFolderAfterExtractionImmutable",
        "closeAfterExtraction",
        "isCloseAfterExtractionImmutable",
        "preservePaths",
        "isPreservePathsImmutable",
        "extractToSubfolder",
        "isExtractToSubfolderImmutable",
        "splitterSizes",
        "QList<int>",
        "isSplitterSizesImmutable",
        "showInfoPanel",
        "isShowInfoPanelImmutable",
        "disabledPlugins",
        "isDisabledPluginsImmutable",
        "limitPreviewFileSize",
        "isLimitPreviewFileSizeImmutable",
        "previewFileSizeLimit",
        "isPreviewFileSizeLimitImmutable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showEncryptionWarningChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultOpenActionChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openDestinationFolderAfterExtractionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeAfterExtractionChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preservePathsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extractToSubfolderChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'splitterSizesChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showInfoPanelChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disabledPluginsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'limitPreviewFileSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewFileSizeLimitChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showEncryptionWarning'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isShowEncryptionWarningImmutable'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOpenAction'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isDefaultOpenActionImmutable'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'openDestinationFolderAfterExtraction'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isOpenDestinationFolderAfterExtractionImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'closeAfterExtraction'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isCloseAfterExtractionImmutable'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preservePaths'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isPreservePathsImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'extractToSubfolder'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isExtractToSubfolderImmutable'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'splitterSizes'
        QtMocHelpers::PropertyData<QList<int>>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'isSplitterSizesImmutable'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showInfoPanel'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isShowInfoPanelImmutable'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disabledPlugins'
        QtMocHelpers::PropertyData<QStringList>(30, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isDisabledPluginsImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limitPreviewFileSize'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isLimitPreviewFileSizeImmutable'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'previewFileSizeLimit'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isPreviewFileSizeLimitImmutable'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ArkSettings, qt_meta_tag_ZN11ArkSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ArkSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ArkSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ArkSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ArkSettingsE_t>.metaTypes,
    nullptr
} };

void ArkSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ArkSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showEncryptionWarningChanged(); break;
        case 1: _t->defaultOpenActionChanged(); break;
        case 2: _t->openDestinationFolderAfterExtractionChanged(); break;
        case 3: _t->closeAfterExtractionChanged(); break;
        case 4: _t->preservePathsChanged(); break;
        case 5: _t->extractToSubfolderChanged(); break;
        case 6: _t->splitterSizesChanged(); break;
        case 7: _t->showInfoPanelChanged(); break;
        case 8: _t->disabledPluginsChanged(); break;
        case 9: _t->limitPreviewFileSizeChanged(); break;
        case 10: _t->previewFileSizeLimitChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::showEncryptionWarningChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::defaultOpenActionChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::openDestinationFolderAfterExtractionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::closeAfterExtractionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::preservePathsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::extractToSubfolderChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::splitterSizesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::showInfoPanelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::disabledPluginsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::limitPreviewFileSizeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArkSettings::*)()>(_a, &ArkSettings::previewFileSizeLimitChanged, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showEncryptionWarning(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isShowEncryptionWarningImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->defaultOpenAction(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDefaultOpenActionImmutable(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->openDestinationFolderAfterExtraction(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isOpenDestinationFolderAfterExtractionImmutable(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->closeAfterExtraction(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isCloseAfterExtractionImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->preservePaths(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isPreservePathsImmutable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->extractToSubfolder(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isExtractToSubfolderImmutable(); break;
        case 12: *reinterpret_cast<QList<int>*>(_v) = _t->splitterSizes(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isSplitterSizesImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->showInfoPanel(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->isShowInfoPanelImmutable(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->disabledPlugins(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isDisabledPluginsImmutable(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->limitPreviewFileSize(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isLimitPreviewFileSizeImmutable(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->previewFileSizeLimit(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->isPreviewFileSizeLimitImmutable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowEncryptionWarning(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setDefaultOpenAction(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setOpenDestinationFolderAfterExtraction(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setCloseAfterExtraction(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setPreservePaths(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setExtractToSubfolder(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setSplitterSizes(*reinterpret_cast<QList<int>*>(_v)); break;
        case 14: _t->setShowInfoPanel(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setDisabledPlugins(*reinterpret_cast<QStringList*>(_v)); break;
        case 18: _t->setLimitPreviewFileSize(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setPreviewFileSizeLimit(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ArkSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ArkSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ArkSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int ArkSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void ArkSettings::showEncryptionWarningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ArkSettings::defaultOpenActionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ArkSettings::openDestinationFolderAfterExtractionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ArkSettings::closeAfterExtractionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ArkSettings::preservePathsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ArkSettings::extractToSubfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ArkSettings::splitterSizesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ArkSettings::showInfoPanelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ArkSettings::disabledPluginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ArkSettings::limitPreviewFileSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ArkSettings::previewFileSizeLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
