/********************************************************************************
** Form generated from reading UI file 'compressionoptionswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COMPRESSIONOPTIONSWIDGET_H
#define UI_COMPRESSIONOPTIONSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcollapsiblegroupbox.h"
#include "kmessagewidget.h"
#include "knewpasswordwidget.h"

QT_BEGIN_NAMESPACE

class Ui_CompressionOptionsWidget
{
public:
    QVBoxLayout *verticalLayout;
    KCollapsibleGroupBox *collapsibleCompression;
    QGridLayout *gridLayout;
    QLabel *lblCompLevel1;
    QLabel *lblCompLevel2;
    QSlider *compLevelSlider;
    QLabel *lblCompMethod;
    QLabel *lblCompLevel3;
    QComboBox *compMethodComboBox;
    KCollapsibleGroupBox *collapsibleEncryption;
    QFormLayout *formLayout_2;
    QLabel *lblEncMethod;
    QComboBox *encMethodComboBox;
    KNewPasswordWidget *pwdWidget;
    QCheckBox *encryptHeaderCheckBox;
    KMessageWidget *warningMsgWidget;
    KCollapsibleGroupBox *collapsibleMultiVolume;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *multiVolumeCheckbox;
    QFormLayout *formLayout;
    QLabel *lblVolumeSize;
    QDoubleSpinBox *volumeSizeSpinbox;

    void setupUi(QWidget *CompressionOptionsWidget)
    {
        if (CompressionOptionsWidget->objectName().isEmpty())
            CompressionOptionsWidget->setObjectName("CompressionOptionsWidget");
        CompressionOptionsWidget->resize(551, 433);
        verticalLayout = new QVBoxLayout(CompressionOptionsWidget);
        verticalLayout->setObjectName("verticalLayout");
        collapsibleCompression = new KCollapsibleGroupBox(CompressionOptionsWidget);
        collapsibleCompression->setObjectName("collapsibleCompression");
        collapsibleCompression->setEnabled(true);
        collapsibleCompression->setExpanded(false);
        gridLayout = new QGridLayout(collapsibleCompression);
        gridLayout->setObjectName("gridLayout");
        lblCompLevel1 = new QLabel(collapsibleCompression);
        lblCompLevel1->setObjectName("lblCompLevel1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(lblCompLevel1->sizePolicy().hasHeightForWidth());
        lblCompLevel1->setSizePolicy(sizePolicy);
        lblCompLevel1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblCompLevel1, 2, 0, 1, 1);

        lblCompLevel2 = new QLabel(collapsibleCompression);
        lblCompLevel2->setObjectName("lblCompLevel2");

        gridLayout->addWidget(lblCompLevel2, 1, 1, 1, 1);

        compLevelSlider = new QSlider(collapsibleCompression);
        compLevelSlider->setObjectName("compLevelSlider");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(3);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(compLevelSlider->sizePolicy().hasHeightForWidth());
        compLevelSlider->setSizePolicy(sizePolicy1);
        compLevelSlider->setMinimumSize(QSize(300, 0));
        compLevelSlider->setMaximum(9);
        compLevelSlider->setPageStep(1);
        compLevelSlider->setOrientation(Qt::Horizontal);
        compLevelSlider->setTickPosition(QSlider::TicksBothSides);
        compLevelSlider->setTickInterval(1);

        gridLayout->addWidget(compLevelSlider, 2, 1, 1, 2);

        lblCompMethod = new QLabel(collapsibleCompression);
        lblCompMethod->setObjectName("lblCompMethod");
        lblCompMethod->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblCompMethod, 0, 0, 1, 1);

        lblCompLevel3 = new QLabel(collapsibleCompression);
        lblCompLevel3->setObjectName("lblCompLevel3");
        lblCompLevel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblCompLevel3, 1, 2, 1, 1);

        compMethodComboBox = new QComboBox(collapsibleCompression);
        compMethodComboBox->setObjectName("compMethodComboBox");

        gridLayout->addWidget(compMethodComboBox, 0, 1, 1, 1);


        verticalLayout->addWidget(collapsibleCompression);

        collapsibleEncryption = new KCollapsibleGroupBox(CompressionOptionsWidget);
        collapsibleEncryption->setObjectName("collapsibleEncryption");
        collapsibleEncryption->setEnabled(true);
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(collapsibleEncryption->sizePolicy().hasHeightForWidth());
        collapsibleEncryption->setSizePolicy(sizePolicy2);
        collapsibleEncryption->setExpanded(false);
        formLayout_2 = new QFormLayout(collapsibleEncryption);
        formLayout_2->setObjectName("formLayout_2");
        lblEncMethod = new QLabel(collapsibleEncryption);
        lblEncMethod->setObjectName("lblEncMethod");
        lblEncMethod->setEnabled(false);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, lblEncMethod);

        encMethodComboBox = new QComboBox(collapsibleEncryption);
        encMethodComboBox->setObjectName("encMethodComboBox");
        encMethodComboBox->setEnabled(false);
        encMethodComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, encMethodComboBox);

        pwdWidget = new KNewPasswordWidget(collapsibleEncryption);
        pwdWidget->setObjectName("pwdWidget");
        pwdWidget->setEnabled(false);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::SpanningRole, pwdWidget);

        encryptHeaderCheckBox = new QCheckBox(collapsibleEncryption);
        encryptHeaderCheckBox->setObjectName("encryptHeaderCheckBox");
        encryptHeaderCheckBox->setEnabled(false);
        encryptHeaderCheckBox->setLayoutDirection(Qt::LeftToRight);
        encryptHeaderCheckBox->setChecked(true);

        formLayout_2->setWidget(3, QFormLayout::ItemRole::SpanningRole, encryptHeaderCheckBox);

        warningMsgWidget = new KMessageWidget(collapsibleEncryption);
        warningMsgWidget->setObjectName("warningMsgWidget");
        warningMsgWidget->setMessageType(KMessageWidget::Warning);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::SpanningRole, warningMsgWidget);


        verticalLayout->addWidget(collapsibleEncryption);

        collapsibleMultiVolume = new KCollapsibleGroupBox(CompressionOptionsWidget);
        collapsibleMultiVolume->setObjectName("collapsibleMultiVolume");
        collapsibleMultiVolume->setExpanded(false);
        verticalLayout_2 = new QVBoxLayout(collapsibleMultiVolume);
        verticalLayout_2->setObjectName("verticalLayout_2");
        multiVolumeCheckbox = new QCheckBox(collapsibleMultiVolume);
        multiVolumeCheckbox->setObjectName("multiVolumeCheckbox");

        verticalLayout_2->addWidget(multiVolumeCheckbox);

        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setVerticalSpacing(0);
        formLayout->setContentsMargins(30, -1, -1, -1);
        lblVolumeSize = new QLabel(collapsibleMultiVolume);
        lblVolumeSize->setObjectName("lblVolumeSize");
        lblVolumeSize->setEnabled(false);
        lblVolumeSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, lblVolumeSize);

        volumeSizeSpinbox = new QDoubleSpinBox(collapsibleMultiVolume);
        volumeSizeSpinbox->setObjectName("volumeSizeSpinbox");
        volumeSizeSpinbox->setEnabled(false);
        volumeSizeSpinbox->setDecimals(1);
        volumeSizeSpinbox->setMinimum(0.100000000000000);
        volumeSizeSpinbox->setMaximum(1000000.000000000000000);
        volumeSizeSpinbox->setSingleStep(0.100000000000000);
        volumeSizeSpinbox->setValue(1.000000000000000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, volumeSizeSpinbox);


        verticalLayout_2->addLayout(formLayout);


        verticalLayout->addWidget(collapsibleMultiVolume);


        retranslateUi(CompressionOptionsWidget);

        QMetaObject::connectSlotsByName(CompressionOptionsWidget);
    } // setupUi

    void retranslateUi(QWidget *CompressionOptionsWidget)
    {
        collapsibleCompression->setTitle(tr2i18n("Compression", nullptr));
        lblCompLevel1->setText(tr2i18n("Level:", nullptr));
        lblCompLevel2->setText(tr2i18n("Min", nullptr));
        lblCompMethod->setText(tr2i18n("Method:", nullptr));
        lblCompLevel3->setText(tr2i18n("Max", nullptr));
        collapsibleEncryption->setTitle(tr2i18n("Password Protection", nullptr));
        lblEncMethod->setText(tr2i18n("Encryption method:", nullptr));
        encryptHeaderCheckBox->setText(tr2i18n("Ask for password before showing the list of files in the archive", nullptr));
        warningMsgWidget->setText(tr2i18n("This encryption method may not be supported by older archiving software.", nullptr));
        collapsibleMultiVolume->setTitle(tr2i18n("Multi-volume Archive", nullptr));
        multiVolumeCheckbox->setText(tr2i18n("Create multi-volume archive", nullptr));
        lblVolumeSize->setText(tr2i18n("Volume size:", nullptr));
        volumeSizeSpinbox->setSuffix(tr2i18n(" megabytes", nullptr));
        (void)CompressionOptionsWidget;
    } // retranslateUi

};

namespace Ui {
    class CompressionOptionsWidget: public Ui_CompressionOptionsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COMPRESSIONOPTIONSWIDGET_H

