/********************************************************************************
** Form generated from reading UI file 'createdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEDIALOG_H
#define UI_CREATEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <compressionoptionswidget.h>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CreateDialog
{
public:
    QVBoxLayout *verticalLayout;
    QVBoxLayout *vlayout;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *destFolderUrlRequester;
    QLabel *label_3;
    QLineEdit *filenameLineEdit;
    QLabel *label_2;
    QComboBox *mimeComboBox;
    QLabel *label_4;
    QCheckBox *chkAddExtension;
    Kerfuffle::CompressionOptionsWidget *optionsWidget;
    QFrame *line;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *CreateDialog)
    {
        if (CreateDialog->objectName().isEmpty())
            CreateDialog->setObjectName("CreateDialog");
        CreateDialog->resize(502, 369);
        CreateDialog->setMinimumSize(QSize(400, 0));
        verticalLayout = new QVBoxLayout(CreateDialog);
        verticalLayout->setObjectName("verticalLayout");
        vlayout = new QVBoxLayout();
        vlayout->setObjectName("vlayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setSizeConstraint(QLayout::SetFixedSize);
        label = new QLabel(CreateDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        destFolderUrlRequester = new KUrlRequester(CreateDialog);
        destFolderUrlRequester->setObjectName("destFolderUrlRequester");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(destFolderUrlRequester->sizePolicy().hasHeightForWidth());
        destFolderUrlRequester->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, destFolderUrlRequester);

        label_3 = new QLabel(CreateDialog);
        label_3->setObjectName("label_3");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        filenameLineEdit = new QLineEdit(CreateDialog);
        filenameLineEdit->setObjectName("filenameLineEdit");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, filenameLineEdit);

        label_2 = new QLabel(CreateDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        mimeComboBox = new QComboBox(CreateDialog);
        mimeComboBox->setObjectName("mimeComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mimeComboBox->sizePolicy().hasHeightForWidth());
        mimeComboBox->setSizePolicy(sizePolicy1);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, mimeComboBox);

        label_4 = new QLabel(CreateDialog);
        label_4->setObjectName("label_4");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_4);

        chkAddExtension = new QCheckBox(CreateDialog);
        chkAddExtension->setObjectName("chkAddExtension");
        chkAddExtension->setText(QString::fromUtf8("Automatically add filename extension (extension)"));
        chkAddExtension->setChecked(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, chkAddExtension);


        vlayout->addLayout(formLayout);

        optionsWidget = new Kerfuffle::CompressionOptionsWidget(CreateDialog);
        optionsWidget->setObjectName("optionsWidget");

        vlayout->addWidget(optionsWidget);

        line = new QFrame(CreateDialog);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        vlayout->addWidget(line);

        buttonBox = new QDialogButtonBox(CreateDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vlayout->addWidget(buttonBox);


        verticalLayout->addLayout(vlayout);

        QWidget::setTabOrder(destFolderUrlRequester, filenameLineEdit);
        QWidget::setTabOrder(filenameLineEdit, mimeComboBox);

        retranslateUi(CreateDialog);

        QMetaObject::connectSlotsByName(CreateDialog);
    } // setupUi

    void retranslateUi(QWidget *CreateDialog)
    {
        label->setText(tr2i18n("Folder:", nullptr));
        label_3->setText(tr2i18n("Filename:", nullptr));
        filenameLineEdit->setPlaceholderText(tr2i18n("Type archive name\342\200\246", nullptr));
        label_2->setText(tr2i18n("Type:", nullptr));
        label_4->setText(tr2i18n("Extension:", nullptr));
        (void)CreateDialog;
    } // retranslateUi

};

namespace Ui {
    class CreateDialog: public Ui_CreateDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CREATEDIALOG_H

