/********************************************************************************
** Form generated from reading UI file 'previewsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PREVIEWSETTINGSPAGE_H
#define UI_PREVIEWSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PreviewSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_limitPreviewFileSize;
    QSpinBox *kcfg_previewFileSizeLimit;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PreviewSettingsPage)
    {
        if (PreviewSettingsPage->objectName().isEmpty())
            PreviewSettingsPage->setObjectName("PreviewSettingsPage");
        PreviewSettingsPage->resize(547, 487);
        verticalLayout = new QVBoxLayout(PreviewSettingsPage);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_limitPreviewFileSize = new QCheckBox(PreviewSettingsPage);
        kcfg_limitPreviewFileSize->setObjectName("kcfg_limitPreviewFileSize");
        kcfg_limitPreviewFileSize->setEnabled(true);
        kcfg_limitPreviewFileSize->setChecked(true);

        horizontalLayout->addWidget(kcfg_limitPreviewFileSize);

        kcfg_previewFileSizeLimit = new QSpinBox(PreviewSettingsPage);
        kcfg_previewFileSizeLimit->setObjectName("kcfg_previewFileSizeLimit");
        kcfg_previewFileSizeLimit->setMinimum(10);
        kcfg_previewFileSizeLimit->setMaximum(10000);
        kcfg_previewFileSizeLimit->setSingleStep(10);
        kcfg_previewFileSizeLimit->setValue(200);

        horizontalLayout->addWidget(kcfg_previewFileSizeLimit);


        verticalLayout->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(PreviewSettingsPage);

        QMetaObject::connectSlotsByName(PreviewSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *PreviewSettingsPage)
    {
        kcfg_limitPreviewFileSize->setText(tr2i18n("Disable preview for files larger than:", nullptr));
        kcfg_previewFileSizeLimit->setSuffix(tr2i18n(" megabytes", nullptr));
        (void)PreviewSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class PreviewSettingsPage: public Ui_PreviewSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PREVIEWSETTINGSPAGE_H

