/****************************************************************************
** Meta object code from reading C++ file 'cliproperties.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/kerfuffle/cliproperties.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cliproperties.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::CliProperties::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::CliProperties",
        "addProgram",
        "deleteProgram",
        "extractProgram",
        "listProgram",
        "moveProgram",
        "testProgram",
        "addSwitch",
        "commentSwitch",
        "deleteSwitch",
        "extractSwitch",
        "extractSwitchNoPreserve",
        "listSwitch",
        "moveSwitch",
        "testSwitch",
        "passwordSwitch",
        "passwordSwitchHeaderEnc",
        "compressionLevelSwitch",
        "compressionMethodSwitch",
        "QHash<QString,QVariant>",
        "encryptionMethodSwitch",
        "multiVolumeSwitch",
        "testPassedPatterns",
        "fileExistsFileNameRegExp",
        "fileExistsInput",
        "multiVolumeSuffix",
        "captureProgress"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'addProgram'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'deleteProgram'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'extractProgram'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'listProgram'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'moveProgram'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'testProgram'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'addSwitch'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'commentSwitch'
        QtMocHelpers::PropertyData<QStringList>(8, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'deleteSwitch'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'extractSwitch'
        QtMocHelpers::PropertyData<QStringList>(10, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'extractSwitchNoPreserve'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'listSwitch'
        QtMocHelpers::PropertyData<QStringList>(12, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'moveSwitch'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'testSwitch'
        QtMocHelpers::PropertyData<QStringList>(14, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'passwordSwitch'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'passwordSwitchHeaderEnc'
        QtMocHelpers::PropertyData<QStringList>(16, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'compressionLevelSwitch'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'compressionMethodSwitch'
        QtMocHelpers::PropertyData<QHash<QString,QVariant>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'encryptionMethodSwitch'
        QtMocHelpers::PropertyData<QHash<QString,QVariant>>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'multiVolumeSwitch'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'testPassedPatterns'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'fileExistsFileNameRegExp'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'fileExistsInput'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'multiVolumeSuffix'
        QtMocHelpers::PropertyData<QStringList>(25, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'captureProgress'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CliProperties, qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::CliProperties::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::CliProperties::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CliProperties *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_addProgram; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_deleteProgram; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_extractProgram; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_listProgram; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_moveProgram; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_testProgram; break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->m_addSwitch; break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->m_commentSwitch; break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->m_deleteSwitch; break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->m_extractSwitch; break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->m_extractSwitchNoPreserve; break;
        case 11: *reinterpret_cast<QStringList*>(_v) = _t->m_listSwitch; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->m_moveSwitch; break;
        case 13: *reinterpret_cast<QStringList*>(_v) = _t->m_testSwitch; break;
        case 14: *reinterpret_cast<QStringList*>(_v) = _t->m_passwordSwitch; break;
        case 15: *reinterpret_cast<QStringList*>(_v) = _t->m_passwordSwitchHeaderEnc; break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->m_compressionLevelSwitch; break;
        case 17: *reinterpret_cast<QHash<QString,QVariant>*>(_v) = _t->m_compressionMethodSwitch; break;
        case 18: *reinterpret_cast<QHash<QString,QVariant>*>(_v) = _t->m_encryptionMethodSwitch; break;
        case 19: *reinterpret_cast<QString*>(_v) = _t->m_multiVolumeSwitch; break;
        case 20: *reinterpret_cast<QStringList*>(_v) = _t->m_testPassedPatterns; break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->m_fileExistsFileNameRegExp; break;
        case 22: *reinterpret_cast<QStringList*>(_v) = _t->m_fileExistsInput; break;
        case 23: *reinterpret_cast<QStringList*>(_v) = _t->m_multiVolumeSuffix; break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->m_captureProgress; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_addProgram, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_deleteProgram, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_extractProgram, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_listProgram, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_moveProgram, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_testProgram, *reinterpret_cast<QString*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_addSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_commentSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_deleteSwitch, *reinterpret_cast<QString*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->m_extractSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->m_extractSwitchNoPreserve, *reinterpret_cast<QStringList*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->m_listSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_moveSwitch, *reinterpret_cast<QString*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->m_testSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 14: QtMocHelpers::setProperty(_t->m_passwordSwitch, *reinterpret_cast<QStringList*>(_v)); break;
        case 15: QtMocHelpers::setProperty(_t->m_passwordSwitchHeaderEnc, *reinterpret_cast<QStringList*>(_v)); break;
        case 16: QtMocHelpers::setProperty(_t->m_compressionLevelSwitch, *reinterpret_cast<QString*>(_v)); break;
        case 17: QtMocHelpers::setProperty(_t->m_compressionMethodSwitch, *reinterpret_cast<QHash<QString,QVariant>*>(_v)); break;
        case 18: QtMocHelpers::setProperty(_t->m_encryptionMethodSwitch, *reinterpret_cast<QHash<QString,QVariant>*>(_v)); break;
        case 19: QtMocHelpers::setProperty(_t->m_multiVolumeSwitch, *reinterpret_cast<QString*>(_v)); break;
        case 20: QtMocHelpers::setProperty(_t->m_testPassedPatterns, *reinterpret_cast<QStringList*>(_v)); break;
        case 21: QtMocHelpers::setProperty(_t->m_fileExistsFileNameRegExp, *reinterpret_cast<QStringList*>(_v)); break;
        case 22: QtMocHelpers::setProperty(_t->m_fileExistsInput, *reinterpret_cast<QStringList*>(_v)); break;
        case 23: QtMocHelpers::setProperty(_t->m_multiVolumeSuffix, *reinterpret_cast<QStringList*>(_v)); break;
        case 24: QtMocHelpers::setProperty(_t->m_captureProgress, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Kerfuffle::CliProperties::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::CliProperties::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle13CliPropertiesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kerfuffle::CliProperties::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}
QT_WARNING_POP
