/****************************************************************************
** Meta object code from reading C++ file 'archiveentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/kerfuffle/archiveentry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archiveentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::Archive::Entry::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::Archive::Entry",
        "fullPath",
        "name",
        "displayName",
        "permissions",
        "owner",
        "group",
        "size",
        "compressedSize",
        "sparseSize",
        "link",
        "ratio",
        "CRC",
        "BLAKE2",
        "method",
        "version",
        "timestamp",
        "isDirectory",
        "isExecutable",
        "isPasswordProtected",
        "isSparse"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fullPath'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'permissions'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'owner'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'group'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'size'
        QtMocHelpers::PropertyData<qulonglong>(7, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'compressedSize'
        QtMocHelpers::PropertyData<qulonglong>(8, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'sparseSize'
        QtMocHelpers::PropertyData<qulonglong>(9, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'link'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'ratio'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'CRC'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'BLAKE2'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'method'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'version'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'timestamp'
        QtMocHelpers::PropertyData<QDateTime>(16, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isDirectory'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isExecutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isPasswordProtected'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isSparse'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Entry, qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::Archive::Entry::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::Archive::Entry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Entry *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_fullPath; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_permissions; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_owner; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_group; break;
        case 6: *reinterpret_cast<qulonglong*>(_v) = _t->m_size; break;
        case 7: *reinterpret_cast<qulonglong*>(_v) = _t->m_compressedSize; break;
        case 8: *reinterpret_cast<qulonglong*>(_v) = _t->m_sparseSize; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->m_link; break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->m_ratio; break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->m_CRC; break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->m_BLAKE2; break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->m_method; break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->m_version; break;
        case 15: *reinterpret_cast<QDateTime*>(_v) = _t->m_timestamp; break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->m_isDirectory; break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->m_isExecutable; break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->m_isPasswordProtected; break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->m_isSparse; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFullPath(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDisplayName(*reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_permissions, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_owner, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_group, *reinterpret_cast<QString*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_size, *reinterpret_cast<qulonglong*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_compressedSize, *reinterpret_cast<qulonglong*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_sparseSize, *reinterpret_cast<qulonglong*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->m_link, *reinterpret_cast<QString*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->m_ratio, *reinterpret_cast<QString*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->m_CRC, *reinterpret_cast<QString*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_BLAKE2, *reinterpret_cast<QString*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->m_method, *reinterpret_cast<QString*>(_v)); break;
        case 14: QtMocHelpers::setProperty(_t->m_version, *reinterpret_cast<QString*>(_v)); break;
        case 15: QtMocHelpers::setProperty(_t->m_timestamp, *reinterpret_cast<QDateTime*>(_v)); break;
        case 16: _t->setIsDirectory(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setIsExecutable(*reinterpret_cast<bool*>(_v)); break;
        case 18: QtMocHelpers::setProperty(_t->m_isPasswordProtected, *reinterpret_cast<bool*>(_v)); break;
        case 19: QtMocHelpers::setProperty(_t->m_isSparse, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Kerfuffle::Archive::Entry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::Archive::Entry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7Archive5EntryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kerfuffle::Archive::Entry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
