/********************************************************************************
** Form generated from reading UI file 'extractiondialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTRACTIONDIALOG_H
#define UI_EXTRACTIONDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"

QT_BEGIN_NAMESPACE

class Ui_ExtractionDialog
{
public:
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *iconLabel;
    QLabel *extractAllLabel;
    QGroupBox *singleFolderGroup;
    QVBoxLayout *verticalLayout;
    KLineEdit *subfolder;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QCheckBox *openFolderCheckBox;
    QCheckBox *closeAfterExtraction;
    QCheckBox *preservePaths;
    QCheckBox *autoSubfolders;
    QSpacerItem *gridLayoutVerticalSpacer;
    QGroupBox *filesToExtractGroupBox;
    QVBoxLayout *vboxLayout;
    QRadioButton *selectedFilesButton;
    QRadioButton *allFilesButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ExtractionDialog)
    {
        if (ExtractionDialog->objectName().isEmpty())
            ExtractionDialog->setObjectName("ExtractionDialog");
        ExtractionDialog->resize(314, 422);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ExtractionDialog->sizePolicy().hasHeightForWidth());
        ExtractionDialog->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(ExtractionDialog);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        iconLabel = new QLabel(ExtractionDialog);
        iconLabel->setObjectName("iconLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(iconLabel->sizePolicy().hasHeightForWidth());
        iconLabel->setSizePolicy(sizePolicy1);
        iconLabel->setMaximumSize(QSize(256, 256));
        iconLabel->setPixmap(QPixmap(QString::fromUtf8("../../../../../kde-devel/ark-trunk/pics/ox32-action-ark_extract.png")));
        iconLabel->setScaledContents(false);
        iconLabel->setAlignment(Qt::AlignCenter);

        horizontalLayout->addWidget(iconLabel);

        extractAllLabel = new QLabel(ExtractionDialog);
        extractAllLabel->setObjectName("extractAllLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(extractAllLabel->sizePolicy().hasHeightForWidth());
        extractAllLabel->setSizePolicy(sizePolicy2);
        QFont font;
        font.setPointSize(11);
        font.setBold(false);
        extractAllLabel->setFont(font);

        horizontalLayout->addWidget(extractAllLabel);


        verticalLayout_2->addLayout(horizontalLayout);

        singleFolderGroup = new QGroupBox(ExtractionDialog);
        singleFolderGroup->setObjectName("singleFolderGroup");
        singleFolderGroup->setCheckable(true);
        singleFolderGroup->setChecked(false);
        singleFolderGroup->setFlat(true);
        verticalLayout = new QVBoxLayout(singleFolderGroup);
        verticalLayout->setObjectName("verticalLayout");
        subfolder = new KLineEdit(singleFolderGroup);
        subfolder->setObjectName("subfolder");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(subfolder->sizePolicy().hasHeightForWidth());
        subfolder->setSizePolicy(sizePolicy3);
        subfolder->setProperty("showClearButton", QVariant(true));

        verticalLayout->addWidget(subfolder);


        verticalLayout_2->addWidget(singleFolderGroup);

        groupBox = new QGroupBox(ExtractionDialog);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy4);
        groupBox->setFlat(true);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        openFolderCheckBox = new QCheckBox(groupBox);
        openFolderCheckBox->setObjectName("openFolderCheckBox");

        gridLayout->addWidget(openFolderCheckBox, 2, 0, 1, 1);

        closeAfterExtraction = new QCheckBox(groupBox);
        closeAfterExtraction->setObjectName("closeAfterExtraction");

        gridLayout->addWidget(closeAfterExtraction, 3, 0, 1, 1);

        preservePaths = new QCheckBox(groupBox);
        preservePaths->setObjectName("preservePaths");

        gridLayout->addWidget(preservePaths, 4, 0, 1, 1);

        autoSubfolders = new QCheckBox(groupBox);
        autoSubfolders->setObjectName("autoSubfolders");

        gridLayout->addWidget(autoSubfolders, 5, 0, 1, 1);

        gridLayoutVerticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(gridLayoutVerticalSpacer, 6, 0, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        filesToExtractGroupBox = new QGroupBox(ExtractionDialog);
        filesToExtractGroupBox->setObjectName("filesToExtractGroupBox");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(filesToExtractGroupBox->sizePolicy().hasHeightForWidth());
        filesToExtractGroupBox->setSizePolicy(sizePolicy5);
        filesToExtractGroupBox->setFlat(true);
        filesToExtractGroupBox->setCheckable(false);
        vboxLayout = new QVBoxLayout(filesToExtractGroupBox);
        vboxLayout->setObjectName("vboxLayout");
        selectedFilesButton = new QRadioButton(filesToExtractGroupBox);
        selectedFilesButton->setObjectName("selectedFilesButton");
        sizePolicy3.setHeightForWidth(selectedFilesButton->sizePolicy().hasHeightForWidth());
        selectedFilesButton->setSizePolicy(sizePolicy3);
        selectedFilesButton->setChecked(true);

        vboxLayout->addWidget(selectedFilesButton);

        allFilesButton = new QRadioButton(filesToExtractGroupBox);
        allFilesButton->setObjectName("allFilesButton");
        sizePolicy3.setHeightForWidth(allFilesButton->sizePolicy().hasHeightForWidth());
        allFilesButton->setSizePolicy(sizePolicy3);

        vboxLayout->addWidget(allFilesButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(verticalSpacer);


        verticalLayout_2->addWidget(filesToExtractGroupBox);


        retranslateUi(ExtractionDialog);

        QMetaObject::connectSlotsByName(ExtractionDialog);
    } // setupUi

    void retranslateUi(QWidget *ExtractionDialog)
    {
        ExtractionDialog->setWindowTitle(tr2i18n("Extraction Dialog", nullptr));
        iconLabel->setText(QString());
        extractAllLabel->setText(tr2i18n("Extract All Files", nullptr));
        singleFolderGroup->setTitle(tr2i18n("E&xtraction into subfolder:", nullptr));
        groupBox->setTitle(tr2i18n("Options", nullptr));
        openFolderCheckBox->setText(tr2i18n("Open &destination folder after extraction", nullptr));
        closeAfterExtraction->setText(tr2i18n("Close &Ark after extraction", nullptr));
        preservePaths->setText(tr2i18n("&Preserve paths when extracting", nullptr));
        autoSubfolders->setText(tr2i18n("&Automatically create subfolders", nullptr));
        filesToExtractGroupBox->setTitle(tr2i18n("Extract", "@title:group"));
        selectedFilesButton->setText(tr2i18n("Sele&cted files only", nullptr));
        allFilesButton->setText(tr2i18n("All &files", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExtractionDialog: public Ui_ExtractionDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTRACTIONDIALOG_H

