/********************************************************************************
** Form generated from reading UI file 'propertiesdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROPERTIESDIALOG_H
#define UI_PROPERTIESDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PropertiesDialog
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout_2;
    QFormLayout *formLayout;
    QLabel *label;
    QLabel *lblArchiveName;
    QLabel *label_4;
    QLabel *lblArchiveType;
    QLabel *label_11;
    QLabel *lblMimetype;
    QLabel *label_8;
    QLabel *lblReadOnly;
    QLabel *label_2;
    QLabel *lblPasswordProtected;
    QLabel *label_10;
    QLabel *lblHasComment;
    QLabel *label_3;
    QLabel *lblNumberOfEntries;
    QLabel *label_5;
    QLabel *lblUnpackedSize;
    QLabel *label_7;
    QLabel *lblPackedSize;
    QLabel *label_9;
    QLabel *lblCompressionRatio;
    QLabel *label_6;
    QLabel *lblLastModified;
    QLabel *label_12;
    QLabel *lblMD5;
    QLabel *label_13;
    QLabel *lblSHA1;
    QLabel *label_14;
    QLabel *lblSHA256;
    QLabel *label_15;
    QLabel *lblMultiVolume;
    QLabel *label_16;
    QLabel *lblCompressionMethods;
    QLabel *lblIcon;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *PropertiesDialog)
    {
        if (PropertiesDialog->objectName().isEmpty())
            PropertiesDialog->setObjectName("PropertiesDialog");
        PropertiesDialog->resize(730, 443);
        verticalLayout = new QVBoxLayout(PropertiesDialog);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(12, 12, 12, 12);
        groupBox = new QGroupBox(PropertiesDialog);
        groupBox->setObjectName("groupBox");
        horizontalLayout_2 = new QHBoxLayout(groupBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        lblArchiveName = new QLabel(groupBox);
        lblArchiveName->setObjectName("lblArchiveName");
        lblArchiveName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, lblArchiveName);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_4);

        lblArchiveType = new QLabel(groupBox);
        lblArchiveType->setObjectName("lblArchiveType");
        lblArchiveType->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, lblArchiveType);

        label_11 = new QLabel(groupBox);
        label_11->setObjectName("label_11");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_11);

        lblMimetype = new QLabel(groupBox);
        lblMimetype->setObjectName("lblMimetype");
        lblMimetype->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, lblMimetype);

        label_8 = new QLabel(groupBox);
        label_8->setObjectName("label_8");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_8);

        lblReadOnly = new QLabel(groupBox);
        lblReadOnly->setObjectName("lblReadOnly");
        lblReadOnly->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, lblReadOnly);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_2);

        lblPasswordProtected = new QLabel(groupBox);
        lblPasswordProtected->setObjectName("lblPasswordProtected");
        lblPasswordProtected->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, lblPasswordProtected);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName("label_10");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_10);

        lblHasComment = new QLabel(groupBox);
        lblHasComment->setObjectName("lblHasComment");
        lblHasComment->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, lblHasComment);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_3);

        lblNumberOfEntries = new QLabel(groupBox);
        lblNumberOfEntries->setObjectName("lblNumberOfEntries");
        lblNumberOfEntries->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, lblNumberOfEntries);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_5);

        lblUnpackedSize = new QLabel(groupBox);
        lblUnpackedSize->setObjectName("lblUnpackedSize");
        lblUnpackedSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, lblUnpackedSize);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_7);

        lblPackedSize = new QLabel(groupBox);
        lblPackedSize->setObjectName("lblPackedSize");
        lblPackedSize->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, lblPackedSize);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_9);

        lblCompressionRatio = new QLabel(groupBox);
        lblCompressionRatio->setObjectName("lblCompressionRatio");
        lblCompressionRatio->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, lblCompressionRatio);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, label_6);

        lblLastModified = new QLabel(groupBox);
        lblLastModified->setObjectName("lblLastModified");
        lblLastModified->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, lblLastModified);

        label_12 = new QLabel(groupBox);
        label_12->setObjectName("label_12");

        formLayout->setWidget(13, QFormLayout::ItemRole::LabelRole, label_12);

        lblMD5 = new QLabel(groupBox);
        lblMD5->setObjectName("lblMD5");
        lblMD5->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        lblMD5->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(13, QFormLayout::ItemRole::FieldRole, lblMD5);

        label_13 = new QLabel(groupBox);
        label_13->setObjectName("label_13");

        formLayout->setWidget(14, QFormLayout::ItemRole::LabelRole, label_13);

        lblSHA1 = new QLabel(groupBox);
        lblSHA1->setObjectName("lblSHA1");
        lblSHA1->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(14, QFormLayout::ItemRole::FieldRole, lblSHA1);

        label_14 = new QLabel(groupBox);
        label_14->setObjectName("label_14");

        formLayout->setWidget(15, QFormLayout::ItemRole::LabelRole, label_14);

        lblSHA256 = new QLabel(groupBox);
        lblSHA256->setObjectName("lblSHA256");
        lblSHA256->setText(QString::fromUtf8("nnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnnn"));
        lblSHA256->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, lblSHA256);

        label_15 = new QLabel(groupBox);
        label_15->setObjectName("label_15");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_15);

        lblMultiVolume = new QLabel(groupBox);
        lblMultiVolume->setObjectName("lblMultiVolume");
        lblMultiVolume->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, lblMultiVolume);

        label_16 = new QLabel(groupBox);
        label_16->setObjectName("label_16");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_16);

        lblCompressionMethods = new QLabel(groupBox);
        lblCompressionMethods->setObjectName("lblCompressionMethods");
        lblCompressionMethods->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, lblCompressionMethods);


        horizontalLayout_2->addLayout(formLayout);

        lblIcon = new QLabel(groupBox);
        lblIcon->setObjectName("lblIcon");
        lblIcon->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        horizontalLayout_2->addWidget(lblIcon);


        verticalLayout->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(PropertiesDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(PropertiesDialog);

        QMetaObject::connectSlotsByName(PropertiesDialog);
    } // setupUi

    void retranslateUi(QWidget *PropertiesDialog)
    {
        groupBox->setTitle(QString());
        label->setText(tr2i18n("Archive name:", nullptr));
        lblArchiveName->setText(QString());
        label_4->setText(tr2i18n("Archive type:", nullptr));
        lblArchiveType->setText(QString());
        label_11->setText(tr2i18n("Mime-type:", nullptr));
        lblMimetype->setText(QString());
        label_8->setText(tr2i18n("Opened read-only:", nullptr));
        lblReadOnly->setText(QString());
        label_2->setText(tr2i18n("Password-protected:", nullptr));
        lblPasswordProtected->setText(QString());
        label_10->setText(tr2i18n("Has comment:", nullptr));
        lblHasComment->setText(QString());
        label_3->setText(tr2i18n("Number of entries:", nullptr));
        lblNumberOfEntries->setText(QString());
        label_5->setText(tr2i18n("Unpacked size:", nullptr));
        lblUnpackedSize->setText(QString());
        label_7->setText(tr2i18n("Packed size:", nullptr));
        lblPackedSize->setText(QString());
        label_9->setText(tr2i18n("Compression ratio:", nullptr));
        lblCompressionRatio->setText(QString());
        label_6->setText(tr2i18n("Last modified:", nullptr));
        lblLastModified->setText(QString());
        label_12->setText(tr2i18n("MD5 hash:", nullptr));
        lblMD5->setText(QString());
        label_13->setText(tr2i18n("SHA-1 hash:", nullptr));
        lblSHA1->setText(QString());
        label_14->setText(tr2i18n("SHA-256 hash:", nullptr));
        label_15->setText(tr2i18n("Multi-volume:", nullptr));
        lblMultiVolume->setText(QString());
        label_16->setText(tr2i18n("Compression method(s):", nullptr));
        lblCompressionMethods->setText(QString());
        lblIcon->setText(QString());
        (void)PropertiesDialog;
    } // retranslateUi

};

namespace Ui {
    class PropertiesDialog: public Ui_PropertiesDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROPERTIESDIALOG_H

