/********************************************************************************
** Form generated from reading UI file 'arkviewer.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARKVIEWER_H
#define UI_ARKVIEWER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ArkViewer
{
public:
    QWidget *centralwidget;
    QVBoxLayout *mainLayout;
    QWidget *m_mimeWidget;
    QHBoxLayout *horizontalLayout;
    QLabel *m_iconLabel;
    QLabel *m_commentLabel;
    QSpacerItem *horizontalSpacer;

    void setupUi(QMainWindow *ArkViewer)
    {
        if (ArkViewer->objectName().isEmpty())
            ArkViewer->setObjectName("ArkViewer");
        ArkViewer->resize(800, 600);
        ArkViewer->setWindowTitle(QString::fromUtf8("MainWindow"));
        centralwidget = new QWidget(ArkViewer);
        centralwidget->setObjectName("centralwidget");
        mainLayout = new QVBoxLayout(centralwidget);
        mainLayout->setSpacing(0);
        mainLayout->setObjectName("mainLayout");
        mainLayout->setContentsMargins(0, 0, 0, 0);
        m_mimeWidget = new QWidget(centralwidget);
        m_mimeWidget->setObjectName("m_mimeWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_mimeWidget->sizePolicy().hasHeightForWidth());
        m_mimeWidget->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(m_mimeWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(-1, 0, -1, 0);
        m_iconLabel = new QLabel(m_mimeWidget);
        m_iconLabel->setObjectName("m_iconLabel");
        m_iconLabel->setText(QString::fromUtf8("mime icon"));

        horizontalLayout->addWidget(m_iconLabel);

        m_commentLabel = new QLabel(m_mimeWidget);
        m_commentLabel->setObjectName("m_commentLabel");
        m_commentLabel->setText(QString::fromUtf8("mime comment"));

        horizontalLayout->addWidget(m_commentLabel);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        mainLayout->addWidget(m_mimeWidget);

        ArkViewer->setCentralWidget(centralwidget);

        retranslateUi(ArkViewer);

        QMetaObject::connectSlotsByName(ArkViewer);
    } // setupUi

    void retranslateUi(QMainWindow *ArkViewer)
    {
        (void)ArkViewer;
    } // retranslateUi

};

namespace Ui {
    class ArkViewer: public Ui_ArkViewer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARKVIEWER_H

