/********************************************************************************
** Form generated from reading UI file 'extractionsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXTRACTIONSETTINGSPAGE_H
#define UI_EXTRACTIONSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ExtractionSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_openDestinationFolderAfterExtraction;
    QCheckBox *kcfg_closeAfterExtraction;
    QCheckBox *kcfg_preservePaths;
    QCheckBox *kcfg_extractToSubfolder;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ExtractionSettingsPage)
    {
        if (ExtractionSettingsPage->objectName().isEmpty())
            ExtractionSettingsPage->setObjectName("ExtractionSettingsPage");
        ExtractionSettingsPage->resize(544, 487);
        verticalLayout = new QVBoxLayout(ExtractionSettingsPage);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_openDestinationFolderAfterExtraction = new QCheckBox(ExtractionSettingsPage);
        kcfg_openDestinationFolderAfterExtraction->setObjectName("kcfg_openDestinationFolderAfterExtraction");

        verticalLayout->addWidget(kcfg_openDestinationFolderAfterExtraction);

        kcfg_closeAfterExtraction = new QCheckBox(ExtractionSettingsPage);
        kcfg_closeAfterExtraction->setObjectName("kcfg_closeAfterExtraction");

        verticalLayout->addWidget(kcfg_closeAfterExtraction);

        kcfg_preservePaths = new QCheckBox(ExtractionSettingsPage);
        kcfg_preservePaths->setObjectName("kcfg_preservePaths");
        kcfg_preservePaths->setChecked(true);

        verticalLayout->addWidget(kcfg_preservePaths);

        kcfg_extractToSubfolder = new QCheckBox(ExtractionSettingsPage);
        kcfg_extractToSubfolder->setObjectName("kcfg_extractToSubfolder");
        kcfg_extractToSubfolder->setChecked(true);

        verticalLayout->addWidget(kcfg_extractToSubfolder);

        verticalSpacer = new QSpacerItem(20, 388, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ExtractionSettingsPage);

        QMetaObject::connectSlotsByName(ExtractionSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *ExtractionSettingsPage)
    {
        kcfg_openDestinationFolderAfterExtraction->setText(tr2i18n("Open destination folder after extraction", nullptr));
        kcfg_closeAfterExtraction->setText(tr2i18n("Close Ark after extraction", nullptr));
        kcfg_preservePaths->setText(tr2i18n("Preserve paths when extracting", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_extractToSubfolder->setToolTip(tr2i18n("Whether to check by default the extraction into subfolder checkbox in the Extraction Dialog, when the archive has more than one top-level entry.", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_extractToSubfolder->setText(tr2i18n("Extract to a subfolder if the archive has more than one top-level entry", nullptr));
        (void)ExtractionSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class ExtractionSettingsPage: public Ui_ExtractionSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXTRACTIONSETTINGSPAGE_H

