/****************************************************************************
** Meta object code from reading C++ file 'part.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/part/part.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'part.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Ark4PartE_t {};
} // unnamed namespace

template <> constexpr inline auto Ark::Part::qt_create_metaobjectdata<qt_meta_tag_ZN3Ark4PartE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Ark::Part",
        "busy",
        "",
        "ready",
        "quit",
        "extractSelectedFilesTo",
        "localPath",
        "slotCompleted",
        "slotLoadingStarted",
        "slotLoadingFinished",
        "KJob*",
        "job",
        "slotOpenExtractedEntry",
        "slotPreviewExtractedEntry",
        "slotOpenEntry",
        "mode",
        "slotError",
        "errorMessage",
        "details",
        "slotExtractArchive",
        "slotShowExtractionDialog",
        "slotExtractionDone",
        "slotQuickExtractFiles",
        "QAction*",
        "slotAddFiles",
        "files",
        "const Kerfuffle::Archive::Entry*",
        "destination",
        "relPath",
        "Ark::Part::OverwriteBehaviour",
        "onOverwrite",
        "slotDroppedFiles",
        "slotPasteFiles",
        "QList<Kerfuffle::Archive::Entry*>&",
        "Kerfuffle::Archive::Entry*",
        "entriesWithoutChildren",
        "slotCutFiles",
        "slotCopyFiles",
        "slotRenameFile",
        "name",
        "slotAddFilesDone",
        "slotPasteFilesDone",
        "slotTestingDone",
        "slotDeleteFiles",
        "slotDeleteFilesDone",
        "slotShowProperties",
        "slotShowContextMenu",
        "slotActivated",
        "QModelIndex",
        "index",
        "slotToggleInfoPanel",
        "slotSaveAs",
        "updateActions",
        "updateQuickExtractMenu",
        "extractAction",
        "selectionChanged",
        "setBusyGui",
        "setReadyGui",
        "setFileNameFromArchive",
        "slotResetFileChangeTimer",
        "file",
        "slotWatchedFileModified",
        "slotShowComment",
        "slotAddComment",
        "slotCommentChanged",
        "slotTestArchive",
        "slotShowFind",
        "displayMsgWidget",
        "KMessageWidget::MessageType",
        "type",
        "msg",
        "searchEdited",
        "text"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'busy'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quit'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractSelectedFilesTo'
        QtMocHelpers::SlotData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadingStarted'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadingFinished'
        QtMocHelpers::SlotData<void(KJob *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotOpenExtractedEntry'
        QtMocHelpers::SlotData<void(KJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotPreviewExtractedEntry'
        QtMocHelpers::SlotData<void(KJob *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotOpenEntry'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'slotError'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'slotExtractArchive'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowExtractionDialog'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExtractionDone'
        QtMocHelpers::SlotData<void(KJob *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotQuickExtractFiles'
        QtMocHelpers::SlotData<void(QAction *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 2 },
        }}),
        // Slot 'slotAddFiles'
        QtMocHelpers::SlotData<void(const QStringList &, const Kerfuffle::Archive::Entry *, const QString &, Ark::Part::OverwriteBehaviour)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 25 }, { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotAddFiles'
        QtMocHelpers::SlotData<void(const QStringList &, const Kerfuffle::Archive::Entry *, const QString &)>(24, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 25 }, { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 },
        }}),
        // Slot 'slotDroppedFiles'
        QtMocHelpers::SlotData<void(const QStringList &, const Kerfuffle::Archive::Entry *)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'slotPasteFiles'
        QtMocHelpers::SlotData<void(QList<Kerfuffle::Archive::Entry*> &, Kerfuffle::Archive::Entry *, int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 33, 25 }, { 0x80000000 | 34, 27 }, { QMetaType::Int, 35 },
        }}),
        // Slot 'slotAddFiles'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCutFiles'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyFiles'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameFile'
        QtMocHelpers::SlotData<void(const QString &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 39 },
        }}),
        // Slot 'slotPasteFiles'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddFilesDone'
        QtMocHelpers::SlotData<void(KJob *)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotPasteFilesDone'
        QtMocHelpers::SlotData<void(KJob *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotTestingDone'
        QtMocHelpers::SlotData<void(KJob *)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotDeleteFiles'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteFilesDone'
        QtMocHelpers::SlotData<void(KJob *)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 },
        }}),
        // Slot 'slotShowProperties'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowContextMenu'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'slotToggleInfoPanel'
        QtMocHelpers::SlotData<void(bool)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotSaveAs'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateActions'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateQuickExtractMenu'
        QtMocHelpers::SlotData<void(QAction *)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 54 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setBusyGui'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setReadyGui'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setFileNameFromArchive'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResetFileChangeTimer'
        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'slotWatchedFileModified'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'slotShowComment'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddComment'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCommentChanged'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotTestArchive'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowFind'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayMsgWidget'
        QtMocHelpers::SlotData<void(KMessageWidget::MessageType, const QString &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 68, 69 }, { QMetaType::QString, 70 },
        }}),
        // Slot 'searchEdited'
        QtMocHelpers::SlotData<void(const QString &)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 72 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Part, qt_meta_tag_ZN3Ark4PartE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Ark::Part::staticMetaObject = { {
    QMetaObject::SuperData::link<KParts::ReadWritePart::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Ark4PartE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Ark4PartE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Ark4PartE_t>.metaTypes,
    nullptr
} };

void Ark::Part::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Part *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->busy(); break;
        case 1: _t->ready(); break;
        case 2: _t->quit(); break;
        case 3: _t->extractSelectedFilesTo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->slotCompleted(); break;
        case 5: _t->slotLoadingStarted(); break;
        case 6: _t->slotLoadingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 7: _t->slotOpenExtractedEntry((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 8: _t->slotPreviewExtractedEntry((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->slotOpenEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->slotError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->slotExtractArchive(); break;
        case 12: _t->slotShowExtractionDialog(); break;
        case 13: _t->slotExtractionDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 14: _t->slotQuickExtractFiles((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 15: _t->slotAddFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Kerfuffle::Archive::Entry*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Ark::Part::OverwriteBehaviour>>(_a[4]))); break;
        case 16: _t->slotAddFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Kerfuffle::Archive::Entry*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->slotDroppedFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Kerfuffle::Archive::Entry*>>(_a[2]))); break;
        case 18: _t->slotPasteFiles((*reinterpret_cast<std::add_pointer_t<QList<Kerfuffle::Archive::Entry*>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 19: _t->slotAddFiles(); break;
        case 20: _t->slotCutFiles(); break;
        case 21: _t->slotCopyFiles(); break;
        case 22: _t->slotRenameFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->slotPasteFiles(); break;
        case 24: _t->slotAddFilesDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 25: _t->slotPasteFilesDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 26: _t->slotTestingDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 27: _t->slotDeleteFiles(); break;
        case 28: _t->slotDeleteFilesDone((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 29: _t->slotShowProperties(); break;
        case 30: _t->slotShowContextMenu(); break;
        case 31: _t->slotActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 32: _t->slotToggleInfoPanel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 33: _t->slotSaveAs(); break;
        case 34: _t->updateActions(); break;
        case 35: _t->updateQuickExtractMenu((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 36: _t->selectionChanged(); break;
        case 37: _t->setBusyGui(); break;
        case 38: _t->setReadyGui(); break;
        case 39: _t->setFileNameFromArchive(); break;
        case 40: _t->slotResetFileChangeTimer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 41: _t->slotWatchedFileModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 42: _t->slotShowComment(); break;
        case 43: _t->slotAddComment(); break;
        case 44: _t->slotCommentChanged(); break;
        case 45: _t->slotTestArchive(); break;
        case 46: _t->slotShowFind(); break;
        case 47: _t->displayMsgWidget((*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 48: _t->searchEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Part::*)()>(_a, &Part::busy, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Part::*)()>(_a, &Part::ready, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Part::*)()>(_a, &Part::quit, 2))
            return;
    }
}

const QMetaObject *Ark::Part::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Ark::Part::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Ark4PartE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Interface"))
        return static_cast< Interface*>(this);
    if (!strcmp(_clname, "org.kde.kerfuffle.partinterface/0.43"))
        return static_cast< Interface*>(this);
    return KParts::ReadWritePart::qt_metacast(_clname);
}

int Ark::Part::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadWritePart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 49)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 49;
    }
    return _id;
}

// SIGNAL 0
void Ark::Part::busy()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Ark::Part::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Ark::Part::quit()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
