/****************************************************************************
** Meta object code from reading C++ file 'jobs.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/kerfuffle/jobs.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'jobs.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Kerfuffle3JobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::Job::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle3JobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::Job",
        "entryRemoved",
        "",
        "entry",
        "newEntry",
        "Kerfuffle::Archive::Entry*",
        "userQuery",
        "Kerfuffle::Query*",
        "doWork",
        "onCancelled",
        "onError",
        "message",
        "details",
        "errorCode",
        "onInfo",
        "info",
        "onEntry",
        "onProgress",
        "progress",
        "onEntryRemoved",
        "path",
        "onFinished",
        "result",
        "onUserQuery",
        "query"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entryRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'newEntry'
        QtMocHelpers::SignalData<void(Kerfuffle::Archive::Entry *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'userQuery'
        QtMocHelpers::SignalData<void(Kerfuffle::Query *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCancelled'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(const QString &, const QString &, int)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'onInfo'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'onEntry'
        QtMocHelpers::SlotData<void(Kerfuffle::Archive::Entry *)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 5, 3 },
        }}),
        // Slot 'onProgress'
        QtMocHelpers::SlotData<void(double)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Double, 18 },
        }}),
        // Slot 'onEntryRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'onUserQuery'
        QtMocHelpers::SlotData<void(Kerfuffle::Query *)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Job, qt_meta_tag_ZN9Kerfuffle3JobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::Job::staticMetaObject = { {
    QMetaObject::SuperData::link<KJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle3JobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle3JobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle3JobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::Job::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Job *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->newEntry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        case 2: _t->userQuery((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Query*>>(_a[1]))); break;
        case 3: _t->doWork(); break;
        case 4: _t->onCancelled(); break;
        case 5: _t->onError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->onInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->onEntry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        case 8: _t->onProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 9: _t->onEntryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onUserQuery((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Query*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Query* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Query* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Job::*)(const QString & )>(_a, &Job::entryRemoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(Kerfuffle::Archive::Entry * )>(_a, &Job::newEntry, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Job::*)(Kerfuffle::Query * )>(_a, &Job::userQuery, 2))
            return;
    }
}

const QMetaObject *Kerfuffle::Job::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::Job::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle3JobE_t>.strings))
        return static_cast<void*>(this);
    return KJob::qt_metacast(_clname);
}

int Kerfuffle::Job::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void Kerfuffle::Job::entryRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Kerfuffle::Job::newEntry(Kerfuffle::Archive::Entry * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Kerfuffle::Job::userQuery(Kerfuffle::Query * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle7LoadJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::LoadJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::LoadJob",
        "doWork",
        "",
        "onFinished",
        "result",
        "onNewEntry",
        "const Kerfuffle::Archive::Entry*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'onNewEntry'
        QtMocHelpers::SlotData<void(const Kerfuffle::Archive::Entry *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LoadJob, qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::LoadJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::LoadJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LoadJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->onNewEntry((*reinterpret_cast<std::add_pointer_t<const Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kerfuffle::LoadJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::LoadJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7LoadJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::LoadJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::BatchExtractJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::BatchExtractJob",
        "doWork",
        "",
        "slotLoadingProgress",
        "progress",
        "slotExtractProgress",
        "slotLoadingFinished",
        "KJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoadingProgress'
        QtMocHelpers::SlotData<void(double)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'slotExtractProgress'
        QtMocHelpers::SlotData<void(double)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 4 },
        }}),
        // Slot 'slotLoadingFinished'
        QtMocHelpers::SlotData<void(KJob *)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BatchExtractJob, qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::BatchExtractJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::BatchExtractJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BatchExtractJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->slotLoadingProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->slotExtractProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 3: _t->slotLoadingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *Kerfuffle::BatchExtractJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::BatchExtractJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle15BatchExtractJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::BatchExtractJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle9CreateJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::CreateJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::CreateJob",
        "doWork",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CreateJob, qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::CreateJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::CreateJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CreateJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::CreateJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::CreateJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9CreateJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::CreateJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::ExtractJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::ExtractJob",
        "doWork",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ExtractJob, qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::ExtractJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::ExtractJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ExtractJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::ExtractJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::ExtractJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10ExtractJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::ExtractJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::TempExtractJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::TempExtractJob",
        "doWork",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TempExtractJob, qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::TempExtractJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::TempExtractJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TempExtractJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::TempExtractJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::TempExtractJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle14TempExtractJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::TempExtractJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::PreviewJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::PreviewJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PreviewJob, qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::PreviewJob::staticMetaObject = { {
    QMetaObject::SuperData::link<TempExtractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::PreviewJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PreviewJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Kerfuffle::PreviewJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::PreviewJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10PreviewJobE_t>.strings))
        return static_cast<void*>(this);
    return TempExtractJob::qt_metacast(_clname);
}

int Kerfuffle::PreviewJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TempExtractJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle7OpenJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::OpenJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::OpenJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenJob, qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::OpenJob::staticMetaObject = { {
    QMetaObject::SuperData::link<TempExtractJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::OpenJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Kerfuffle::OpenJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::OpenJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7OpenJobE_t>.strings))
        return static_cast<void*>(this);
    return TempExtractJob::qt_metacast(_clname);
}

int Kerfuffle::OpenJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TempExtractJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::OpenWithJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::OpenWithJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenWithJob, qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::OpenWithJob::staticMetaObject = { {
    QMetaObject::SuperData::link<OpenJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::OpenWithJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenWithJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Kerfuffle::OpenWithJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::OpenWithJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle11OpenWithJobE_t>.strings))
        return static_cast<void*>(this);
    return OpenJob::qt_metacast(_clname);
}

int Kerfuffle::OpenWithJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = OpenJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle6AddJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::AddJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle6AddJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::AddJob",
        "doWork",
        "",
        "onFinished",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AddJob, qt_meta_tag_ZN9Kerfuffle6AddJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::AddJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle6AddJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle6AddJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle6AddJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::AddJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AddJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kerfuffle::AddJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::AddJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle6AddJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::AddJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle7MoveJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::MoveJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::MoveJob",
        "doWork",
        "",
        "onFinished",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MoveJob, qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::MoveJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::MoveJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MoveJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kerfuffle::MoveJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::MoveJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7MoveJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::MoveJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle7CopyJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::CopyJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::CopyJob",
        "doWork",
        "",
        "onFinished",
        "result"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CopyJob, qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::CopyJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::CopyJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CopyJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->onFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Kerfuffle::CopyJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::CopyJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7CopyJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::CopyJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::DeleteJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::DeleteJob",
        "doWork",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DeleteJob, qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::DeleteJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::DeleteJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeleteJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::DeleteJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::DeleteJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle9DeleteJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::DeleteJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle10CommentJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::CommentJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::CommentJob",
        "doWork",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CommentJob, qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::CommentJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::CommentJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommentJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::CommentJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::CommentJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle10CommentJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::CommentJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle7TestJobE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::TestJob::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7TestJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::TestJob",
        "doWork",
        "",
        "onTestSuccess"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doWork'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTestSuccess'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TestJob, qt_meta_tag_ZN9Kerfuffle7TestJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::TestJob::staticMetaObject = { {
    QMetaObject::SuperData::link<Job::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7TestJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7TestJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7TestJobE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::TestJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TestJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doWork(); break;
        case 1: _t->onTestSuccess(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *Kerfuffle::TestJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::TestJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7TestJobE_t>.strings))
        return static_cast<void*>(this);
    return Job::qt_metacast(_clname);
}

int Kerfuffle::TestJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
