/********************************************************************************
** Form generated from reading UI file 'pluginsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLUGINSETTINGSPAGE_H
#define UI_PLUGINSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PluginSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QTreeWidget *kcfg_disabledPlugins;

    void setupUi(QWidget *PluginSettingsPage)
    {
        if (PluginSettingsPage->objectName().isEmpty())
            PluginSettingsPage->setObjectName("PluginSettingsPage");
        PluginSettingsPage->resize(547, 487);
        verticalLayout = new QVBoxLayout(PluginSettingsPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_disabledPlugins = new QTreeWidget(PluginSettingsPage);
        kcfg_disabledPlugins->setObjectName("kcfg_disabledPlugins");
        kcfg_disabledPlugins->setRootIsDecorated(false);
        kcfg_disabledPlugins->setColumnCount(2);

        verticalLayout->addWidget(kcfg_disabledPlugins);


        retranslateUi(PluginSettingsPage);

        QMetaObject::connectSlotsByName(PluginSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *PluginSettingsPage)
    {
        QTreeWidgetItem *___qtreewidgetitem = kcfg_disabledPlugins->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Description", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Name", nullptr));
        (void)PluginSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class PluginSettingsPage: public Ui_PluginSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PLUGINSETTINGSPAGE_H

