/****************************************************************************
** Meta object code from reading C++ file 'archive_kerfuffle.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/kerfuffle/archive_kerfuffle.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archive_kerfuffle.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Kerfuffle7ArchiveE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::Archive::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::Archive",
        "onAddFinished",
        "",
        "KJob*",
        "onUserQuery",
        "Kerfuffle::Query*",
        "onCompressionMethodFound",
        "method",
        "onEncryptionMethodFound",
        "completeBaseName",
        "fileName",
        "comment",
        "mimeType",
        "QMimeType",
        "isEmpty",
        "isReadOnly",
        "isSingleFile",
        "isSingleFolder",
        "isMultiVolume",
        "numberOfVolumes",
        "encryptionType",
        "EncryptionType",
        "numberOfEntries",
        "unpackedSize",
        "packedSize",
        "subfolderName",
        "password",
        "compressionMethods",
        "encryptionMethods",
        "Unencrypted",
        "Encrypted",
        "HeaderEncrypted"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAddFinished'
        QtMocHelpers::SlotData<void(KJob *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'onUserQuery'
        QtMocHelpers::SlotData<void(Kerfuffle::Query *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'onCompressionMethodFound'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'onEncryptionMethodFound'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'completeBaseName'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fileName'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mimeType'
        QtMocHelpers::PropertyData<QMimeType>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'isEmpty'
        QtMocHelpers::PropertyData<bool>(14, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isReadOnly'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isSingleFile'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'isSingleFolder'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isMultiVolume'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'numberOfVolumes'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'encryptionType'
        QtMocHelpers::PropertyData<enum EncryptionType>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'numberOfEntries'
        QtMocHelpers::PropertyData<uint>(22, QMetaType::UInt, QMC::DefaultPropertyFlags),
        // property 'unpackedSize'
        QtMocHelpers::PropertyData<qulonglong>(23, QMetaType::ULongLong, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'packedSize'
        QtMocHelpers::PropertyData<qulonglong>(24, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'subfolderName'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'password'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'compressionMethods'
        QtMocHelpers::PropertyData<QStringList>(27, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'encryptionMethods'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EncryptionType'
        QtMocHelpers::EnumData<enum EncryptionType>(21, 21, QMC::EnumFlags{}).add({
            {   29, EncryptionType::Unencrypted },
            {   30, EncryptionType::Encrypted },
            {   31, EncryptionType::HeaderEncrypted },
        }),
    };
    return QtMocHelpers::metaObjectData<Archive, qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::Archive::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::Archive::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Archive *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAddFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 1: _t->onUserQuery((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Query*>>(_a[1]))); break;
        case 2: _t->onCompressionMethodFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->onEncryptionMethodFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->completeBaseName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fileName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->comment(); break;
        case 3: *reinterpret_cast<QMimeType*>(_v) = _t->mimeType(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isEmpty(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isReadOnly(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isSingleFile(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isSingleFolder(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isMultiVolume(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->numberOfVolumes(); break;
        case 10: *reinterpret_cast<enum EncryptionType*>(_v) = _t->encryptionType(); break;
        case 11: *reinterpret_cast<uint*>(_v) = _t->numberOfEntries(); break;
        case 12: *reinterpret_cast<qulonglong*>(_v) = _t->unpackedSize(); break;
        case 13: *reinterpret_cast<qulonglong*>(_v) = _t->packedSize(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->subfolderName(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->password(); break;
        case 16: *reinterpret_cast<QStringList*>(_v) = _t->m_compressionMethods; break;
        case 17: *reinterpret_cast<QStringList*>(_v) = _t->m_encryptionMethods; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 7: QtMocHelpers::setProperty(_t->m_isSingleFolder, *reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setMultiVolume(*reinterpret_cast<bool*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->m_encryptionType, *reinterpret_cast<enum EncryptionType*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_extractedFilesSize, *reinterpret_cast<qulonglong*>(_v)); break;
        case 14: QtMocHelpers::setProperty(_t->m_subfolderName, *reinterpret_cast<QString*>(_v)); break;
        case 16: QtMocHelpers::setProperty(_t->m_compressionMethods, *reinterpret_cast<QStringList*>(_v)); break;
        case 17: QtMocHelpers::setProperty(_t->m_encryptionMethods, *reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Kerfuffle::Archive::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::Archive::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle7ArchiveE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kerfuffle::Archive::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    return _id;
}
QT_WARNING_POP
