/********************************************************************************
** Form generated from reading UI file 'welcomeview.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WELCOMEVIEW_H
#define UI_WELCOMEVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_WelcomeView
{
public:
    QWidget *scrollAreaWidgetContents;
    QGridLayout *layoutRoot;
    QSpacerItem *spacer6;
    QSpacerItem *spacer4;
    QFrame *frameContent;
    QVBoxLayout *layoutContent;
    QWidget *widgetHeader;
    QHBoxLayout *layoutHeader;
    QSpacerItem *spacer1;
    QLabel *labelIcon;
    QWidget *widgetAbout;
    QVBoxLayout *verticalAbout;
    QLabel *labelTitle;
    QLabel *labelDescription;
    QSpacerItem *spacer2;
    QHBoxLayout *layoutPanels;
    QWidget *widgetRecentFiles;
    QGridLayout *layoutRecentFiles;
    QPushButton *buttonOpenArchive;
    QPushButton *buttonNewArchive;
    QPushButton *buttonClearRecentFiles;
    QListView *listViewRecentFiles;
    QLabel *labelRecentFiles;
    QSpacerItem *spacer3;
    QWidget *widgetHelp;
    QVBoxLayout *layoutHelp;
    QLabel *labelHelp;
    KUrlLabel *labelHomepage;
    KUrlLabel *labelHandbook;
    QSpacerItem *spacer11;
    QWidget *widgetFooter;
    QHBoxLayout *layoutFooter;
    QSpacerItem *spacer9;
    QCheckBox *checkBoxShowOnStartup;
    QSpacerItem *spacer10;
    QSpacerItem *spacer5;
    QSpacerItem *spacer7;
    QWidget *widgetClose;
    QHBoxLayout *layoutClose;
    QPushButton *buttonClose;

    void setupUi(QScrollArea *WelcomeView)
    {
        if (WelcomeView->objectName().isEmpty())
            WelcomeView->setObjectName("WelcomeView");
        WelcomeView->resize(1011, 803);
        WelcomeView->setAcceptDrops(true);
        WelcomeView->setFrameShape(QFrame::NoFrame);
        WelcomeView->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 1011, 803));
        layoutRoot = new QGridLayout(scrollAreaWidgetContents);
        layoutRoot->setSpacing(0);
        layoutRoot->setObjectName("layoutRoot");
        layoutRoot->setContentsMargins(0, 0, 0, 0);
        spacer6 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutRoot->addItem(spacer6, 0, 1, 1, 1);

        spacer4 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutRoot->addItem(spacer4, 1, 0, 1, 1);

        frameContent = new QFrame(scrollAreaWidgetContents);
        frameContent->setObjectName("frameContent");
        layoutContent = new QVBoxLayout(frameContent);
        layoutContent->setSpacing(20);
        layoutContent->setObjectName("layoutContent");
        widgetHeader = new QWidget(frameContent);
        widgetHeader->setObjectName("widgetHeader");
        layoutHeader = new QHBoxLayout(widgetHeader);
        layoutHeader->setObjectName("layoutHeader");
        layoutHeader->setContentsMargins(0, 0, 0, 0);
        spacer1 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutHeader->addItem(spacer1);

        labelIcon = new QLabel(widgetHeader);
        labelIcon->setObjectName("labelIcon");

        layoutHeader->addWidget(labelIcon, 0, Qt::AlignVCenter);

        widgetAbout = new QWidget(widgetHeader);
        widgetAbout->setObjectName("widgetAbout");
        verticalAbout = new QVBoxLayout(widgetAbout);
        verticalAbout->setObjectName("verticalAbout");
        verticalAbout->setContentsMargins(0, 0, 0, 0);
        labelTitle = new QLabel(widgetAbout);
        labelTitle->setObjectName("labelTitle");

        verticalAbout->addWidget(labelTitle);

        labelDescription = new QLabel(widgetAbout);
        labelDescription->setObjectName("labelDescription");

        verticalAbout->addWidget(labelDescription);


        layoutHeader->addWidget(widgetAbout, 0, Qt::AlignVCenter);

        spacer2 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutHeader->addItem(spacer2);

        layoutHeader->setStretch(0, 1);
        layoutHeader->setStretch(3, 1);

        layoutContent->addWidget(widgetHeader);

        layoutPanels = new QHBoxLayout();
        layoutPanels->setSpacing(20);
        layoutPanels->setObjectName("layoutPanels");
        widgetRecentFiles = new QWidget(frameContent);
        widgetRecentFiles->setObjectName("widgetRecentFiles");
        layoutRecentFiles = new QGridLayout(widgetRecentFiles);
        layoutRecentFiles->setObjectName("layoutRecentFiles");
        layoutRecentFiles->setHorizontalSpacing(20);
        layoutRecentFiles->setContentsMargins(0, 0, 0, 0);
        buttonOpenArchive = new QPushButton(widgetRecentFiles);
        buttonOpenArchive->setObjectName("buttonOpenArchive");

        layoutRecentFiles->addWidget(buttonOpenArchive, 2, 0, 1, 1);

        buttonNewArchive = new QPushButton(widgetRecentFiles);
        buttonNewArchive->setObjectName("buttonNewArchive");

        layoutRecentFiles->addWidget(buttonNewArchive, 1, 0, 1, 1);

        buttonClearRecentFiles = new QPushButton(widgetRecentFiles);
        buttonClearRecentFiles->setObjectName("buttonClearRecentFiles");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-clear-all")));
        buttonClearRecentFiles->setIcon(icon);

        layoutRecentFiles->addWidget(buttonClearRecentFiles, 0, 2, 1, 1);

        listViewRecentFiles = new QListView(widgetRecentFiles);
        listViewRecentFiles->setObjectName("listViewRecentFiles");
        listViewRecentFiles->setMinimumSize(QSize(400, 200));
        listViewRecentFiles->setContextMenuPolicy(Qt::CustomContextMenu);
        listViewRecentFiles->setEditTriggers(QAbstractItemView::NoEditTriggers);
        listViewRecentFiles->setAlternatingRowColors(true);

        layoutRecentFiles->addWidget(listViewRecentFiles, 1, 1, 3, 2);

        labelRecentFiles = new QLabel(widgetRecentFiles);
        labelRecentFiles->setObjectName("labelRecentFiles");
        labelRecentFiles->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        layoutRecentFiles->addWidget(labelRecentFiles, 0, 1, 1, 1);

        spacer3 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutRecentFiles->addItem(spacer3, 3, 0, 1, 1);

        layoutRecentFiles->setRowStretch(3, 1);
        layoutRecentFiles->setColumnStretch(1, 1);

        layoutPanels->addWidget(widgetRecentFiles);

        widgetHelp = new QWidget(frameContent);
        widgetHelp->setObjectName("widgetHelp");
        layoutHelp = new QVBoxLayout(widgetHelp);
        layoutHelp->setObjectName("layoutHelp");
        layoutHelp->setContentsMargins(0, 0, 0, 0);
        labelHelp = new QLabel(widgetHelp);
        labelHelp->setObjectName("labelHelp");
        labelHelp->setAlignment(Qt::AlignBottom|Qt::AlignLeading|Qt::AlignLeft);

        layoutHelp->addWidget(labelHelp);

        labelHomepage = new KUrlLabel(widgetHelp);
        labelHomepage->setObjectName("labelHomepage");
        labelHomepage->setGlowEnabled(false);

        layoutHelp->addWidget(labelHomepage, 0, Qt::AlignLeft);

        labelHandbook = new KUrlLabel(widgetHelp);
        labelHandbook->setObjectName("labelHandbook");
        labelHandbook->setGlowEnabled(false);

        layoutHelp->addWidget(labelHandbook, 0, Qt::AlignLeft);

        spacer11 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutHelp->addItem(spacer11);

        layoutHelp->setStretch(3, 1);

        layoutPanels->addWidget(widgetHelp);

        layoutPanels->setStretch(0, 1);

        layoutContent->addLayout(layoutPanels);

        widgetFooter = new QWidget(frameContent);
        widgetFooter->setObjectName("widgetFooter");
        layoutFooter = new QHBoxLayout(widgetFooter);
        layoutFooter->setObjectName("layoutFooter");
        layoutFooter->setContentsMargins(0, 0, 0, 0);
        spacer9 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutFooter->addItem(spacer9);

        checkBoxShowOnStartup = new QCheckBox(widgetFooter);
        checkBoxShowOnStartup->setObjectName("checkBoxShowOnStartup");

        layoutFooter->addWidget(checkBoxShowOnStartup);

        spacer10 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutFooter->addItem(spacer10);


        layoutContent->addWidget(widgetFooter);

        layoutContent->setStretch(1, 1);

        layoutRoot->addWidget(frameContent, 1, 1, 1, 1);

        spacer5 = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        layoutRoot->addItem(spacer5, 1, 2, 1, 1);

        spacer7 = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutRoot->addItem(spacer7, 2, 1, 1, 1);

        widgetClose = new QWidget(scrollAreaWidgetContents);
        widgetClose->setObjectName("widgetClose");
        layoutClose = new QHBoxLayout(widgetClose);
        layoutClose->setObjectName("layoutClose");
        buttonClose = new QPushButton(widgetClose);
        buttonClose->setObjectName("buttonClose");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("window-close")));
        buttonClose->setIcon(icon1);
        buttonClose->setFlat(true);

        layoutClose->addWidget(buttonClose);


        layoutRoot->addWidget(widgetClose, 0, 2, 1, 1, Qt::AlignRight|Qt::AlignTop);

        layoutRoot->setRowStretch(0, 3);
        layoutRoot->setRowStretch(1, 5);
        layoutRoot->setRowStretch(2, 3);
        layoutRoot->setColumnStretch(0, 3);
        layoutRoot->setColumnStretch(1, 5);
        layoutRoot->setColumnStretch(2, 3);
        WelcomeView->setWidget(scrollAreaWidgetContents);
        QWidget::setTabOrder(buttonNewArchive, buttonOpenArchive);
        QWidget::setTabOrder(buttonOpenArchive, listViewRecentFiles);
        QWidget::setTabOrder(listViewRecentFiles, buttonClearRecentFiles);

        retranslateUi(WelcomeView);

        QMetaObject::connectSlotsByName(WelcomeView);
    } // setupUi

    void retranslateUi(QScrollArea *WelcomeView)
    {
        WelcomeView->setWindowTitle(tr2i18n("Welcome", nullptr));
        buttonOpenArchive->setText(tr2i18n("Open Archive\342\200\246", nullptr));
        buttonNewArchive->setText(tr2i18n("New Archive", nullptr));
#if QT_CONFIG(tooltip)
        buttonClearRecentFiles->setToolTip(tr2i18n("Clear Recent Files", nullptr));
#endif // QT_CONFIG(tooltip)
        labelRecentFiles->setText(tr2i18n("Recent Files", nullptr));
        labelHelp->setText(tr2i18n("Help", nullptr));
        labelHomepage->setText(tr2i18n("Visit homepage", nullptr));
        labelHomepage->setUrl(QString());
        labelHandbook->setText(tr2i18n("Read handbook", nullptr));
        labelHandbook->setUrl(QString());
        checkBoxShowOnStartup->setText(tr2i18n("Show on startup", nullptr));
#if QT_CONFIG(tooltip)
        buttonClose->setToolTip(tr2i18n("Close Welcome Page", nullptr));
#endif // QT_CONFIG(tooltip)
    } // retranslateUi

};

namespace Ui {
    class WelcomeView: public Ui_WelcomeView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WELCOMEVIEW_H

