/****************************************************************************
** Meta object code from reading C++ file 'archivemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/part/archivemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archivemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12ArchiveModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ArchiveModel::qt_create_metaobjectdata<qt_meta_tag_ZN12ArchiveModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ArchiveModel",
        "loadingStarted",
        "",
        "loadingFinished",
        "KJob*",
        "error",
        "details",
        "droppedFiles",
        "files",
        "const Kerfuffle::Archive::Entry*",
        "messageWidget",
        "KMessageWidget::MessageType",
        "type",
        "msg",
        "slotNewEntry",
        "Kerfuffle::Archive::Entry*",
        "entry",
        "slotListEntry",
        "slotLoadingFinished",
        "job",
        "slotEntryRemoved",
        "path",
        "slotUserQuery",
        "Kerfuffle::Query*",
        "query",
        "slotCleanupEmptyDirs"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loadingStarted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingFinished'
        QtMocHelpers::SignalData<void(KJob *)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'droppedFiles'
        QtMocHelpers::SignalData<void(const QStringList &, const Kerfuffle::Archive::Entry *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 }, { 0x80000000 | 9, 2 },
        }}),
        // Signal 'messageWidget'
        QtMocHelpers::SignalData<void(KMessageWidget::MessageType, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'slotNewEntry'
        QtMocHelpers::SlotData<void(Kerfuffle::Archive::Entry *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotListEntry'
        QtMocHelpers::SlotData<void(Kerfuffle::Archive::Entry *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotLoadingFinished'
        QtMocHelpers::SlotData<void(KJob *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 19 },
        }}),
        // Slot 'slotEntryRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'slotUserQuery'
        QtMocHelpers::SlotData<void(Kerfuffle::Query *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'slotCleanupEmptyDirs'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ArchiveModel, qt_meta_tag_ZN12ArchiveModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ArchiveModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ArchiveModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ArchiveModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12ArchiveModelE_t>.metaTypes,
    nullptr
} };

void ArchiveModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ArchiveModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loadingStarted(); break;
        case 1: _t->loadingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->droppedFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<const Kerfuffle::Archive::Entry*>>(_a[2]))); break;
        case 4: _t->messageWidget((*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->slotNewEntry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        case 6: _t->slotListEntry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        case 7: _t->slotLoadingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 8: _t->slotEntryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotUserQuery((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Query*>>(_a[1]))); break;
        case 10: _t->slotCleanupEmptyDirs(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ArchiveModel::*)()>(_a, &ArchiveModel::loadingStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveModel::*)(KJob * )>(_a, &ArchiveModel::loadingFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveModel::*)(const QString & , const QString & )>(_a, &ArchiveModel::error, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveModel::*)(const QStringList & , const Kerfuffle::Archive::Entry * )>(_a, &ArchiveModel::droppedFiles, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveModel::*)(KMessageWidget::MessageType , const QString & )>(_a, &ArchiveModel::messageWidget, 4))
            return;
    }
}

const QMetaObject *ArchiveModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ArchiveModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12ArchiveModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int ArchiveModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void ArchiveModel::loadingStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ArchiveModel::loadingFinished(KJob * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ArchiveModel::error(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ArchiveModel::droppedFiles(const QStringList & _t1, const Kerfuffle::Archive::Entry * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ArchiveModel::messageWidget(KMessageWidget::MessageType _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}
QT_WARNING_POP
