/********************************************************************************
** Form generated from reading UI file 'generalsettingspage.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALSETTINGSPAGE_H
#define UI_GENERALSETTINGSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GeneralSettingsPage
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGroupBox *kcfg_defaultOpenAction;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *radioButton;
    QRadioButton *radioButton_2;
    QFrame *line;
    QCheckBox *kcfg_showEncryptionWarning;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralSettingsPage)
    {
        if (GeneralSettingsPage->objectName().isEmpty())
            GeneralSettingsPage->setObjectName("GeneralSettingsPage");
        GeneralSettingsPage->resize(547, 487);
        verticalLayout = new QVBoxLayout(GeneralSettingsPage);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(GeneralSettingsPage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        kcfg_defaultOpenAction = new QGroupBox(GeneralSettingsPage);
        kcfg_defaultOpenAction->setObjectName("kcfg_defaultOpenAction");
        kcfg_defaultOpenAction->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(kcfg_defaultOpenAction);
        verticalLayout_2->setObjectName("verticalLayout_2");
        radioButton = new QRadioButton(kcfg_defaultOpenAction);
        radioButton->setObjectName("radioButton");
        radioButton->setChecked(true);

        verticalLayout_2->addWidget(radioButton);

        radioButton_2 = new QRadioButton(kcfg_defaultOpenAction);
        radioButton_2->setObjectName("radioButton_2");

        verticalLayout_2->addWidget(radioButton_2);


        verticalLayout->addWidget(kcfg_defaultOpenAction);

        line = new QFrame(GeneralSettingsPage);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        kcfg_showEncryptionWarning = new QCheckBox(GeneralSettingsPage);
        kcfg_showEncryptionWarning->setObjectName("kcfg_showEncryptionWarning");
        kcfg_showEncryptionWarning->setChecked(true);

        verticalLayout->addWidget(kcfg_showEncryptionWarning);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(GeneralSettingsPage);

        QMetaObject::connectSlotsByName(GeneralSettingsPage);
    } // setupUi

    void retranslateUi(QWidget *GeneralSettingsPage)
    {
        label->setText(tr2i18n("When clicking a file in an archive or pressing the Return key:", nullptr));
        kcfg_defaultOpenAction->setTitle(QString());
        radioButton->setText(tr2i18n("Pre&view the file with internal previewer", nullptr));
        radioButton_2->setText(tr2i18n("Open the fi&le with associated application", nullptr));
        kcfg_showEncryptionWarning->setText(tr2i18n("Show a warning when creating zip archives with AES encryption", nullptr));
        (void)GeneralSettingsPage;
    } // retranslateUi

};

namespace Ui {
    class GeneralSettingsPage: public Ui_GeneralSettingsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALSETTINGSPAGE_H

