/****************************************************************************
** Meta object code from reading C++ file 'archiveinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../ark-26.04.2/kerfuffle/archiveinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archiveinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::ReadOnlyArchiveInterface::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::ReadOnlyArchiveInterface",
        "cancelled",
        "",
        "error",
        "message",
        "details",
        "errorCode",
        "entry",
        "Kerfuffle::Archive::Entry*",
        "archiveEntry",
        "progress",
        "info",
        "finished",
        "result",
        "testSuccess",
        "compressionMethodFound",
        "method",
        "encryptionMethodFound",
        "userQuery",
        "Kerfuffle::Query*",
        "query",
        "onEntry"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cancelled'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'entry'
        QtMocHelpers::SignalData<void(Kerfuffle::Archive::Entry *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'progress'
        QtMocHelpers::SignalData<void(double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 10 },
        }}),
        // Signal 'info'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'testSuccess'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compressionMethodFound'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'encryptionMethodFound'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'userQuery'
        QtMocHelpers::SignalData<void(Kerfuffle::Query *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'onEntry'
        QtMocHelpers::SlotData<void(Kerfuffle::Archive::Entry *)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadOnlyArchiveInterface, qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::ReadOnlyArchiveInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::ReadOnlyArchiveInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadOnlyArchiveInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancelled(); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->entry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        case 5: _t->progress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 6: _t->info((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->finished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->testSuccess(); break;
        case 9: _t->compressionMethodFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->encryptionMethodFound((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->userQuery((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Query*>>(_a[1]))); break;
        case 12: _t->onEntry((*reinterpret_cast<std::add_pointer_t<Kerfuffle::Archive::Entry*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Kerfuffle::Archive::Entry* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)()>(_a, &ReadOnlyArchiveInterface::cancelled, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & , const QString & , int )>(_a, &ReadOnlyArchiveInterface::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(Kerfuffle::Archive::Entry * )>(_a, &ReadOnlyArchiveInterface::entry, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(double )>(_a, &ReadOnlyArchiveInterface::progress, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & )>(_a, &ReadOnlyArchiveInterface::info, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(bool )>(_a, &ReadOnlyArchiveInterface::finished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)()>(_a, &ReadOnlyArchiveInterface::testSuccess, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & )>(_a, &ReadOnlyArchiveInterface::compressionMethodFound, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & )>(_a, &ReadOnlyArchiveInterface::encryptionMethodFound, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(Kerfuffle::Query * )>(_a, &ReadOnlyArchiveInterface::userQuery, 11))
            return;
    }
}

const QMetaObject *Kerfuffle::ReadOnlyArchiveInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::ReadOnlyArchiveInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle24ReadOnlyArchiveInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kerfuffle::ReadOnlyArchiveInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Kerfuffle::ReadOnlyArchiveInterface::cancelled()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kerfuffle::ReadOnlyArchiveInterface::error(const QString & _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void Kerfuffle::ReadOnlyArchiveInterface::entry(Kerfuffle::Archive::Entry * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Kerfuffle::ReadOnlyArchiveInterface::progress(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Kerfuffle::ReadOnlyArchiveInterface::info(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Kerfuffle::ReadOnlyArchiveInterface::finished(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Kerfuffle::ReadOnlyArchiveInterface::testSuccess()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Kerfuffle::ReadOnlyArchiveInterface::compressionMethodFound(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Kerfuffle::ReadOnlyArchiveInterface::encryptionMethodFound(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Kerfuffle::ReadOnlyArchiveInterface::userQuery(Kerfuffle::Query * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto Kerfuffle::ReadWriteArchiveInterface::qt_create_metaobjectdata<qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kerfuffle::ReadWriteArchiveInterface",
        "entryRemoved",
        "",
        "path",
        "onEntryRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'entryRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'onEntryRemoved'
        QtMocHelpers::SlotData<void(const QString &)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadWriteArchiveInterface, qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kerfuffle::ReadWriteArchiveInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<ReadOnlyArchiveInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>.metaTypes,
    nullptr
} };

void Kerfuffle::ReadWriteArchiveInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadWriteArchiveInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->entryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->onEntryRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReadWriteArchiveInterface::*)(const QString & )>(_a, &ReadWriteArchiveInterface::entryRemoved, 0))
            return;
    }
}

const QMetaObject *Kerfuffle::ReadWriteArchiveInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kerfuffle::ReadWriteArchiveInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9Kerfuffle25ReadWriteArchiveInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return ReadOnlyArchiveInterface::qt_metacast(_clname);
}

int Kerfuffle::ReadWriteArchiveInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ReadOnlyArchiveInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void Kerfuffle::ReadWriteArchiveInterface::entryRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
