/********************************************************************************
** Form generated from reading UI file 'jobtracker.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_JOBTRACKER_H
#define UI_JOBTRACKER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_JobTrackerWidget
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *descriptionLabel;
    QLabel *informationLabel;
    QProgressBar *progressBar;

    void setupUi(QWidget *JobTrackerWidget)
    {
        if (JobTrackerWidget->objectName().isEmpty())
            JobTrackerWidget->setObjectName("JobTrackerWidget");
        JobTrackerWidget->resize(409, 16);
        hboxLayout = new QHBoxLayout(JobTrackerWidget);
        hboxLayout->setObjectName("hboxLayout");
        hboxLayout->setContentsMargins(4, 1, 4, 1);
        descriptionLabel = new QLabel(JobTrackerWidget);
        descriptionLabel->setObjectName("descriptionLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(descriptionLabel->sizePolicy().hasHeightForWidth());
        descriptionLabel->setSizePolicy(sizePolicy);
        descriptionLabel->setMinimumSize(QSize(50, 0));

        hboxLayout->addWidget(descriptionLabel);

        informationLabel = new QLabel(JobTrackerWidget);
        informationLabel->setObjectName("informationLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(informationLabel->sizePolicy().hasHeightForWidth());
        informationLabel->setSizePolicy(sizePolicy1);
        informationLabel->setMinimumSize(QSize(50, 0));

        hboxLayout->addWidget(informationLabel);

        progressBar = new QProgressBar(JobTrackerWidget);
        progressBar->setObjectName("progressBar");
        sizePolicy.setHeightForWidth(progressBar->sizePolicy().hasHeightForWidth());
        progressBar->setSizePolicy(sizePolicy);
        progressBar->setMinimumSize(QSize(50, 0));
        progressBar->setMaximum(100);
        progressBar->setValue(-1);

        hboxLayout->addWidget(progressBar);


        retranslateUi(JobTrackerWidget);

        QMetaObject::connectSlotsByName(JobTrackerWidget);
    } // setupUi

    void retranslateUi(QWidget *JobTrackerWidget)
    {
        JobTrackerWidget->setWindowTitle(tr2i18n("Job Tracker", nullptr));
        descriptionLabel->setText(tr2i18n("<b>Job Description</b>", nullptr));
        informationLabel->setText(tr2i18n("Some Information about the job", nullptr));
        progressBar->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class JobTrackerWidget: public Ui_JobTrackerWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // JOBTRACKER_H

