/********************************************************************************
** Form generated from reading UI file 'infopanel.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_INFOPANEL_H
#define UI_INFOPANEL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_InformationPanel
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *iconLabel;
    KSqueezedTextLabel *fileName;
    QLabel *additionalInfo;
    QFrame *m_separator;
    QWidget *m_metaDataWidget;
    QGridLayout *gridLayout;
    QLabel *m_typeLabel;
    KSqueezedTextLabel *m_typeValueLabel;
    QLabel *m_ownerLabel;
    KSqueezedTextLabel *m_ownerValueLabel;
    QLabel *m_groupLabel;
    KSqueezedTextLabel *m_groupValueLabel;
    QLabel *m_targetLabel;
    KSqueezedTextLabel *m_targetValueLabel;
    QLabel *m_passwordLabel;
    KSqueezedTextLabel *m_passwordValueLabel;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *InformationPanel)
    {
        if (InformationPanel->objectName().isEmpty())
            InformationPanel->setObjectName("InformationPanel");
        InformationPanel->resize(491, 300);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(InformationPanel->sizePolicy().hasHeightForWidth());
        InformationPanel->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(InformationPanel);
        vboxLayout->setObjectName("vboxLayout");
        iconLabel = new QLabel(InformationPanel);
        iconLabel->setObjectName("iconLabel");
        iconLabel->setAlignment(Qt::AlignCenter);
        iconLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        vboxLayout->addWidget(iconLabel);

        fileName = new KSqueezedTextLabel(InformationPanel);
        fileName->setObjectName("fileName");
        QFont font;
        font.setBold(true);
        fileName->setFont(font);
        fileName->setText(QString::fromUtf8("KSqueezedTextLabel"));
        fileName->setAlignment(Qt::AlignCenter);
        fileName->setWordWrap(true);
        fileName->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);
        fileName->setTextElideMode(Qt::ElideRight);

        vboxLayout->addWidget(fileName);

        additionalInfo = new QLabel(InformationPanel);
        additionalInfo->setObjectName("additionalInfo");
        additionalInfo->setAlignment(Qt::AlignCenter);
        additionalInfo->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        vboxLayout->addWidget(additionalInfo);

        m_separator = new QFrame(InformationPanel);
        m_separator->setObjectName("m_separator");
        m_separator->setFrameShape(QFrame::Shape::HLine);
        m_separator->setFrameShadow(QFrame::Shadow::Sunken);

        vboxLayout->addWidget(m_separator);

        m_metaDataWidget = new QWidget(InformationPanel);
        m_metaDataWidget->setObjectName("m_metaDataWidget");
        m_metaDataWidget->setFont(font);
        gridLayout = new QGridLayout(m_metaDataWidget);
        gridLayout->setObjectName("gridLayout");
        m_typeLabel = new QLabel(m_metaDataWidget);
        m_typeLabel->setObjectName("m_typeLabel");
        m_typeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_typeLabel, 0, 0, 1, 1);

        m_typeValueLabel = new KSqueezedTextLabel(m_metaDataWidget);
        m_typeValueLabel->setObjectName("m_typeValueLabel");
        QFont font1;
        font1.setBold(false);
        m_typeValueLabel->setFont(font1);

        gridLayout->addWidget(m_typeValueLabel, 0, 1, 1, 1);

        m_ownerLabel = new QLabel(m_metaDataWidget);
        m_ownerLabel->setObjectName("m_ownerLabel");
        m_ownerLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_ownerLabel, 1, 0, 1, 1);

        m_ownerValueLabel = new KSqueezedTextLabel(m_metaDataWidget);
        m_ownerValueLabel->setObjectName("m_ownerValueLabel");
        m_ownerValueLabel->setFont(font1);

        gridLayout->addWidget(m_ownerValueLabel, 1, 1, 1, 1);

        m_groupLabel = new QLabel(m_metaDataWidget);
        m_groupLabel->setObjectName("m_groupLabel");
        m_groupLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_groupLabel, 2, 0, 1, 1);

        m_groupValueLabel = new KSqueezedTextLabel(m_metaDataWidget);
        m_groupValueLabel->setObjectName("m_groupValueLabel");
        m_groupValueLabel->setFont(font1);

        gridLayout->addWidget(m_groupValueLabel, 2, 1, 1, 1);

        m_targetLabel = new QLabel(m_metaDataWidget);
        m_targetLabel->setObjectName("m_targetLabel");
        m_targetLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_targetLabel, 3, 0, 1, 1);

        m_targetValueLabel = new KSqueezedTextLabel(m_metaDataWidget);
        m_targetValueLabel->setObjectName("m_targetValueLabel");
        m_targetValueLabel->setFont(font1);

        gridLayout->addWidget(m_targetValueLabel, 3, 1, 1, 1);

        m_passwordLabel = new QLabel(m_metaDataWidget);
        m_passwordLabel->setObjectName("m_passwordLabel");
        m_passwordLabel->setFont(font);
        m_passwordLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(m_passwordLabel, 4, 0, 1, 1);

        m_passwordValueLabel = new KSqueezedTextLabel(m_metaDataWidget);
        m_passwordValueLabel->setObjectName("m_passwordValueLabel");
        m_passwordValueLabel->setFont(font1);

        gridLayout->addWidget(m_passwordValueLabel, 4, 1, 1, 1);


        vboxLayout->addWidget(m_metaDataWidget);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(InformationPanel);

        QMetaObject::connectSlotsByName(InformationPanel);
    } // setupUi

    void retranslateUi(QWidget *InformationPanel)
    {
        InformationPanel->setWindowTitle(tr2i18n("Information Panel", nullptr));
        iconLabel->setText(QString());
        additionalInfo->setText(tr2i18n("Unknown file type", nullptr));
        m_typeLabel->setText(tr2i18n("Type:", nullptr));
        m_ownerLabel->setText(tr2i18n("Owner:", nullptr));
        m_groupLabel->setText(tr2i18n("Group:", nullptr));
        m_targetLabel->setText(tr2i18n("Target:", nullptr));
        m_passwordLabel->setText(tr2i18n("Password-protected:", nullptr));
        m_passwordValueLabel->setText(tr2i18n("yes", nullptr));
    } // retranslateUi

};

namespace Ui {
    class InformationPanel: public Ui_InformationPanel {};
} // namespace Ui

QT_END_NAMESPACE

#endif // INFOPANEL_H

